@import url(http://fonts.googleapis.com/css?family=Press+Start+2P);

img.badge {
    width: 64px;
    height: 64px;
}

body {
    font-family: 'Press Start 2P', cursive;
    background-color: #1E1E1E;
}

.strong {
    font-weight: bold;
    text-decoration: underline;
}

.header {
    color: #C1C1C1;
}

.subheader a {
    color: #D01A55;
}

.content a {
    color: #D01A55;
}

.subheader {
    padding: 20px;
    color: #C1C1C1;
    width: 700px;
    margin-right: auto;
    margin-left: auto;
    text-align: right;
    font-size: 90%;
}

.content {
    background-color: #C1C1C1;
    color: #1E1E1E !important;
    width: 700px;
    margin-right: auto;
    margin-left: auto;

    -moz-border-radius: 10px;
    border-radius: 10px;
    border: 1px solid black;
}

table {
    margin-right: auto;
    margin-left: auto;
    padding: 5px;
}

td {
    padding: 5px;
    word-wrap: break-word;
}

.issuer-table {
    table-layout: fixed;
    width: 100%;
}

.collapsed-row {
    visibility: collapse;
}

.issuer-cell {
    vertical-align: text-top;
    padding-top: 25px;
}

.badge-name {
    width: 50%;
}

.badge-image {
    width: 15%;
    text-align: center;
}

.badge-assertions {
    width: 35%;
}

.badge-assertions ul {
    list-style-type: none;
    margin: 0px;
    padding: 0px;
}

.badge-assertions li {
    padding-left: 15px;
}

li.popup {
    width: 150px;
}

div.popup {
    position: absolute;
    float: left;
    border: 1px solid black;
    background-color: #1E1E1E;
    background-color: rgba(30,30,30,0.75);
}

div.gravatar {
    display: inline-block;
    width: 24px;
    height: 24px;
    padding: 2px;
    margin: 1px;
    background: white;
    
    -webkit-box-shadow: 1px 1px 2px rgba(0,0,0,.5);
    -moz-box-shadow: 1px 1px 2px rgba(0,0,0,.5);

    /* The next two lines are for IE.. silly IE */
    zoom: 1;
    filter: progid:DXImageTransform.Microsoft.Shadow(
        color='#969696', Direction=135, Strength=3);
}

div.gravatar img {
    max-width: 100%;
    max-height: 100%;
}
